import smbus
import time

class i2cinterface99(object):
    def __init__(self):
        self.bus = smbus.SMBus(1)
        self.address = 0x63
    def __readNumber(self):
        self.number = self.bus.read_byte(self.address)
        return self.number
    def __sendMessage(self,cmd,data):
        self.bus.write_byte_data(self.address,cmd,data) 
        time.sleep(0.01)	
    def reset(self):
        self.__sendMessage(0,0)
    def led(self,ledCh,ledState):
        if  ledCh==0:
            try:
                self.__sendMessage(1,ledState) #0:off, 1:of
            except:
                return False
        elif ledCh==1:
            try:
                self.__sendMessage(2,ledState) #0:off, 1:of
            except:
                return False
        return True
    def setSound(self,freq,duration):
        if freq<0 or freq>255:
            return False
        if duration <0 or duration>255:
            return False
        try:
            self.__sendMessage(9,freq) # 200+4800/255*xx
            self.__sendMessage(10,duration) #  50ms*(xx+1) : max 1280ms      
        except:
            return False
        return True     
    def sound(self,status):
        if status != 0 and status != 1:
            return False
        try:
            self.__sendMessage(8,status) # 0:off, 1:of
        except:
            return False
        return True
    def setPinMode(self,pinNo,mode): #pinNo 02:D2 03:D3 04:D4 06:D6 13:D13
        if mode == 0: #OUTPUT
            try:
                self.__sendMessage(21,pinNo)
            except:
                return False
        elif mode == 1: #input
            try:
                self.__sendMessage(20,pinNo)
            except:
                return False
        return True
    def digitalWrite(self,pinNo,status):#pinNo 02:D2 03:D3 04:D4 06:D6 13:D13
        if status == 0: #LOW
            try:
                self.__sendMessage(23,pinNo)
            except:
                return False
        elif status == 1: # HIGH
            try:
                self.__sendMessage(22,pinNo)
            except:
                return False
        return True
    def digitalRead(self,pinNo): #pinNo 02:D2 03:D3 04:D4 06:D6 13:D13
        try:
            self.__sendMessage(24,pinNo)
            time.sleep(0.1)
            self.number =self.__readNumber() # 0:LOW, 1:HIGH
        except:
            return False
        return True,self.number
    def analogWrite(self,pinNo,value):# pinNo 3:D3,6:D6.value 0 to 255
        if value<0 or value >255:
            return False
        if pinNo==3:
            try:
                self.__sendMessage(25,value)
            except:
                return False
        elif pinNo==6:
            try:
                self.__sendMessage(26,value)
            except:
                return False
        return True
                
    def analogRead(self,pinNo):# pin No 0:A0, 1:A1
        try:
            self.__sendMessage(30,pinNo)
            time.sleep(0.1)
            self.hbyte= self.__readNumber()
            self.lbyte= self.__readNumber()
        except:
            return False
        return True,self.hbyte*256+self.lbyte
    def lcdInit(self,type):
        if type == 16:
            try:
                self.__sendMessage(50,16)
            except:
                return False
        elif type == 20:
            try:
                self.__sendMessage(50,20)
            except:
                return False
        return True
    def lcdClear(self):
        try:
            self.__sendMessage(51,0)
        except:
            return False
        return True
    def lcdSetCursorMode(self,blink,cursor):
        if blink == 0 and cursor == 0:
            try:
                self.__sendMessage(52,0)
            except:
                return False
        elif blink == 0 and cursor ==1:
            try:
                self.__sendMessage(52,1)
            except:
                return False
        elif blink == 1 and cursor ==0:
            try:
                self.__sendMessage(52,2)
            except:
                return False
        elif blink == 1 and cursor ==1:
            try:
                self.__sendMessage(52,3)
            except:
                return False
        return True
    def lcdPrint(self,str):
        self.strlen = len(str)   
        for i in range(self.strlen):
            self.s=int(str[i].encode("hex_codec"),16)
            try:
                self.__sendMessage(53,self.s)
            except:
                return False
        return True
    def lcdWrite(self,c):
        try:
                self.__sendMessage(53,c)
        except:
                return False
        return True
    def lcdSetPosition(self,col,line): # col 0 to 15, line 0 to 1
        try:
            self.__sendMessage(55,line)
            self.__sendMessage(54,col)
        except:
            return False
        return True
    def lcdDisplay(self,sw): # 0:off, 1:on
        try:
            self.__sendMessage(56,sw)
        except:
            return False
        return True
    def lcdScroll(self,dir): # 0:left, 1:right
        try:
            self.__sendMessage(57,dir)
        except:
            return False
        return True
    def lcdAutoScroll(self,sw): # 0:off, 1:on
        try:
            self.__sendMessage(58,sw)
        except:
            return False
        return True
            
      
#main
if __name__=='__main__':
	print "main"
	print
	ii = i2cinterface99()
	ii.led(0,1)
	ii.led(1,1)
	ii.lcdInit(16)
	time.sleep(0.1)
	ii.lcdPrint('hello, world')
	time.sleep(1)
	ii.lcdSetPosition(0,1)
	ii.lcdPrint(time.ctime())
	time.sleep(0.5)
	ii.led(0,0)
	ii.led(1,0)
